@@ -7,6 +7,7 @@ OC.L10N.register(
     "Token expired or app not enabled! Reload the page!" : "אישור פג תוקף או יישום לא מופעל! יש לטעון את הדף שוב!",
     "Internal server error! Please check your data/nextcloud.log file for additional information!" : "שגיאת שרת פנימית! נא לעיין בקובץ data/nextcloud.log שאצלך לקבלת פרטים נוספים!",
     "Request failed, Nextcloud is in currently in maintenance mode!" : "הבקשה נכשלה, מערכת Nextcloud נמצאת כרגע במצב תחזוקה!",
+    "Unread articles" : "מאמרים שלא נקראו",
     "News" : "חדשות",
     "An RSS/Atom feed reader" : "קורא ערוצי תוכן מסוג RSS/Atom",
     "Use system cron for updates" : "שימוש ב־cron של המערכת לעדכונים",
@@ -15,6 +16,7 @@ OC.L10N.register(
     "Maximum redirects" : "מספר ניתובים מירבי",
     "Feed fetcher timeout" : "עבר זמן מרבי להזנת ערוץ התוכן",
     "Explore Service URL" : "חקירת נתיב שירות",
+    "For more information check the wiki." : "למידע נוסף יש לבקר בוויקי.",
     "Saved" : "נשמר",
     "Download" : "הורדה",
     "Close" : "סגירה",
@@ -25,6 +27,8 @@ OC.L10N.register(
     "Unstar article" : "הסרת סימון כוכב ממאמר",
     "Keep article unread" : "השארת מאמר עם סימון לא נקרא",
     "Remove keep article unread" : "ביטול השארת מאמר עם סימון לא נקרא",
+    "Username" : "שם משתמש",
+    "No users found" : "לא נמצאו משתמשים",
     "by" : "על ידי",
     "from" : "מאת",
     "Play audio" : "השמע קובץ שמע",
@@ -63,7 +67,6 @@ OC.L10N.register(
     "Folder exists already!" : "התיקייה כבר קיימת!",
     "Credentials" : "פרטי גישה",
     "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "אישורי אימות HTTP בסיסיים חייבים להיות מאוחסנים ללא קידוד! כל אחד עם גישה לשרת או למסד הנתונים יוכלו לגשת אליהם!",
-    "Username" : "שם משתמש",
     "Password" : "סיסמא",
     "New Folder" : "תיקייה חדשה",
     "Create" : "יצירה",
@@ -90,7 +93,6 @@ OC.L10N.register(
     "Deleted folder" : "מחיקת תיקייה",
     "Undo delete folder" : "ביטול מחיקת תיקייה",
     "Starred" : "מסומן",
-    "Unread articles" : "מאמרים שלא נקראו",
     "All articles" : "כל המאמרים",
     "Settings" : "הגדרות",
     "Disable mark read through scrolling" : "ניטרול סימון כנקרא בעקבות גלילה",
