@@ -5,11 +5,15 @@ OC.L10N.register(
     "Request unauthorized. Are you logged in?" : "Pedido não autorizado. Fez o login?",
     "Request forbidden. Are you an admin?" : "Pedido proibido. É um administrador?",
     "Token expired or app not enabled! Reload the page!" : "Token expirou ou aplicação não ativa! Recarregue a página!",
+    "Unread articles" : "Artigos não lidos",
+    "News folders" : "Novas pastas",
+    "Shared with me" : "Partilhadas comigo",
     "Purge interval" : "Intervalo de Purgar",
     "Maximum read count per feed" : "Número máximo de leituras por feed",
     "Maximum redirects" : "Máximo de redirecionamentos",
     "Feed fetcher timeout" : "A obtenção do feed expirou",
     "Explore Service URL" : "Explorar Serviço URL",
+    "Update interval" : "Intervalo de actualização",
     "Saved" : "Guardado",
     "Download" : "Transferir",
     "Close" : "Fechar",
@@ -20,8 +24,12 @@ OC.L10N.register(
     "Unstar article" : "Retirar destaque",
     "Keep article unread" : "Marcar artigo como não lido",
     "Remove keep article unread" : "Remover marcação de artigo não lido",
+    "Share" : "Partilhar",
+    "Username" : "Nome de utilizador",
+    "No users found" : "Não foram encontrados utilizadores",
     "by" : "por",
     "from" : "de",
+    "shared by" : "partilhado por",
     "Play audio" : "Reproduzir áudio",
     "Download audio" : "Transferir áudio",
     "Download video" : "Transferir vídeo",
@@ -57,7 +65,6 @@ OC.L10N.register(
     "Folder exists already!" : "A pasta já existe!",
     "Credentials" : "Credenciais",
     "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "As credenciais de autenticação básica HTTP têm de ser armazenadas de forma não encriptada. Qualquer pessoa com acesso ao servidor ou base de dados poderá vê-las!",
-    "Username" : "Nome de utilizador",
     "Password" : "Senha",
     "New Folder" : "Nova Pasta",
     "Create" : "Criar",
@@ -76,7 +83,6 @@ OC.L10N.register(
     "Deleted folder" : "Apagar pasta",
     "Undo delete folder" : "Anular apagar pasta",
     "Starred" : "Marcado",
-    "Unread articles" : "Artigos não lidos",
     "All articles" : "Todos os artigos",
     "Settings" : "Definições",
     "Disable mark read through scrolling" : "Desativar marcar ler através de movimento",
