@@ -7,18 +7,18 @@ OC.L10N.register(
     "Token expired or app not enabled! Reload the page!" : "Žeton je pretekel ali pa program ni omogočen! Poskusite osvežiti stran!",
     "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Notranja napaka strežnika! Preverite datoteko data/nextcloud.log za podrobnosti!",
     "Request failed, Nextcloud is in currently in maintenance mode!" : "Zahteva je spodletela! Okolje Nextcloud je trenutno v vzdrževalnem načinu!",
-    "News folders" : "Mape novic",
+    "Unread articles" : "Neprebrani prispevki",
     "News" : "Novice",
+    "News folders" : "Mape novic",
     "An RSS/Atom feed reader" : "Bralnik virov RSS/Atom",
     "Use system cron for updates" : "Za posodobitve uporabi sistemski program »cron«",
-    "Disable this if you run a custom updater such as the Python updater included in the app." : "Možnost onemogočite, če uporabljate posodabljalnik po meri, kot je na primer posodabljalnik Python, vključen v programski paket.",
     "Purge interval" : "Časovni razmik odstranjevanja",
     "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored." : "Najkrajši čas, po katerem bodo viri in mape odstranjeni iz podatkovne zbirke. Vrednosti pod 60 sekundami so prezrte.",
     "Maximum read count per feed" : "Največje število prikazanih virov",
     "Defines the maximum amount of articles that can be read per feed which won't be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Določa največje število prispevkov vira, ki bodo ostali vidni po čiščenju zgodovine. Če se pojavljajo starejši prispevki, je določilo nastavljeno prenizko. Vrednost -1 onemogoči izvajanje možnosti.",
     "Maximum redirects" : "Največje število preusmeritev",
     "How many redirects the feed fetcher should follow." : "Koliko preusmeritvam naj sledi bralnik virov",
-    "Feed fetcher timeout" : "Čas nalaganja vira",
+    "Feed fetcher timeout" : "Pridobivanje vira je časovno poteklo",
     "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Čas, namenjen nalaganju virov RSS in Atom. Če traja dlje je nalaganje virov prekinjeno.",
     "Explore Service URL" : "Razišči spletni naslov storitve",
     "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Če je podan, bo prek tega naslova URL storitve potekala poizvedba za vire in njihov izbor. Za preklop v vgrajeno storitev določevanja, mora biti polje prazno.",
@@ -36,8 +36,17 @@ OC.L10N.register(
     "Unstar article" : "Odstrani zvezdico s prispevka",
     "Keep article unread" : "Obdrži kot neprebrano",
     "Remove keep article unread" : "Odstrani možnost ohranjanja prispevkov neprebranih",
+    "Share" : "Souporaba",
+    "Share with users" : "Souporaba z uporabniki",
+    "Username" : "Uporabniško ime",
+    "No users found" : "Ni najdenih uporabnikov",
+    "Error while searching for users" : "Prišlo je do napake med iskanjem uporabnikov",
+    "Share on social media" : "Objava na družbenem omrežju",
+    "I wanted you to see this article" : "Priporočam ogled tega prispevka",
+    "Check out this article" : "Preveri ta prispevek",
     "by" : "od",
     "from" : "od",
+    "shared by" : "omogoča",
     "Play audio" : "Predvajaj zvok",
     "Download audio" : "Prejmi zvok",
     "Download video" : "Prejmi video",
@@ -74,8 +83,8 @@ OC.L10N.register(
     "Folder exists already!" : "Mapa že obstaja!",
     "Credentials" : "Poverila",
     "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Osnovni overitveni podatki HTTP Auth morajo biti shranjeni nekodirani! Vsakdo z dostopom do podatkovne zbirke bo imel omogočen dostop!",
-    "Username" : "Uporabniško ime",
     "Password" : "Geslo",
+    "Auto discover Feed" : "Samodejno odkrivanje Vira",
     "New Folder" : "Nova mapa",
     "Create" : "Ustvari",
     "Explore" : "Razišči",
@@ -101,7 +110,6 @@ OC.L10N.register(
     "Deleted folder" : "Izbrisana mapa",
     "Undo delete folder" : "Razveljavi brisanje mape",
     "Starred" : "Z zvezdico",
-    "Unread articles" : "Neprebrani prispevki",
     "All articles" : "Vsi prispevki",
     "Settings" : "Nastavitve",
     "Disable mark read through scrolling" : "Onemogoči označevanje prebranosti med drsenjem",
