@@ -16,6 +16,7 @@ namespace OCA\News\Db;
 use OCA\News\Utility\Time;
 use OCP\AppFramework\Db\DoesNotExistException;
 use OCP\AppFramework\Db\MultipleObjectsReturnedException;
+use OCP\DB\Exception as DBException;
 use OCP\DB\QueryBuilder\IQueryBuilder;
 use OCP\IDBConnection;
 use OCP\AppFramework\Db\Entity;
@@ -153,4 +154,45 @@ class FeedMapperV2 extends NewsMapperV2
 
         return $this->findEntities($builder);
     }
+
+    /**
+     * @param string   $userId
+     * @param int      $id
+     * @param int|null $maxItemID
+     *
+     * @return int
+     * @throws DBException
+     *
+     * @TODO Update for NC 21
+     */
+    public function read(string $userId, int $id, ?int $maxItemID = null): int
+    {
+        $idBuilder = $this->db->getQueryBuilder();
+        $idBuilder->select('items.id')
+            ->from(ItemMapperV2::TABLE_NAME, 'items')
+            ->innerJoin('items', FeedMapperV2::TABLE_NAME, 'feeds', 'items.feed_id = feeds.id')
+            ->andWhere('feeds.user_id = :userId')
+            ->andWhere('feeds.id = :feedId')
+            ->setParameter('userId', $userId)
+            ->setParameter('feedId', $id);
+
+        if ($maxItemID !== null) {
+            $idBuilder->andWhere('items.id <= :maxItemId')
+                      ->setParameter('maxItemId', $maxItemID);
+        }
+
+        $idList = array_map(function ($value): int {
+            return intval($value['id']);
+        }, $this->db->executeQuery($idBuilder->getSQL(), $idBuilder->getParameters())->fetchAll());
+
+        $builder = $this->db->getQueryBuilder();
+        $builder->update(ItemMapperV2::TABLE_NAME)
+            ->set('unread', $builder->createParameter('unread'))
+            ->andWhere('id IN (:idList)')
+            ->andWhere('unread != :unread')
+            ->setParameter('unread', false, IQueryBuilder::PARAM_BOOL)
+            ->setParameter('idList', $idList, IQueryBuilder::PARAM_INT_ARRAY);
+
+        return $this->db->executeUpdate($builder->getSQL(), $builder->getParameters(), $builder->getParameterTypes());
+    }
 }
