@@ -311,7 +311,7 @@ class ItemMapperV2 extends NewsMapperV2
     /**
      * @param string $userId
      * @param int    $feedId
-     * @param float  $updatedSince
+     * @param int    $updatedSince
      * @param bool   $hideRead
      *
      * @return Item[]
@@ -319,7 +319,7 @@ class ItemMapperV2 extends NewsMapperV2
     public function findAllInFeedAfter(
         string $userId,
         int $feedId,
-        float $updatedSince,
+        int $updatedSince,
         bool $hideRead
     ): array {
         $builder = $this->db->getQueryBuilder();
@@ -332,7 +332,7 @@ class ItemMapperV2 extends NewsMapperV2
             ->andWhere('feeds.id = :feedId')
             ->andWhere('feeds.deleted_at = 0')
             ->setParameters([
-                'updatedSince' => number_format($updatedSince, 0, '.', ''),
+                'updatedSince' => $updatedSince,
                 'feedId' => $feedId,
                 'userId'=> $userId,
             ])
@@ -349,7 +349,7 @@ class ItemMapperV2 extends NewsMapperV2
     /**
      * @param string   $userId
      * @param int|null $folderId
-     * @param float    $updatedSince
+     * @param int      $updatedSince
      * @param bool     $hideRead
      *
      * @return Item[]
@@ -357,7 +357,7 @@ class ItemMapperV2 extends NewsMapperV2
     public function findAllInFolderAfter(
         string $userId,
         ?int $folderId,
-        float $updatedSince,
+        int $updatedSince,
         bool $hideRead
     ): array {
         $builder = $this->db->getQueryBuilder();
@@ -370,11 +370,7 @@ class ItemMapperV2 extends NewsMapperV2
             ->andWhere('feeds.user_id = :userId')
             ->andWhere('feeds.deleted_at = 0')
             ->andWhere('folders.id = :folderId')
-            ->setParameters([
-                'updatedSince' => number_format($updatedSince, 0, '.', ''),
-                'folderId' => $folderId,
-                'userId' => $userId,
-            ])
+            ->setParameters(['updatedSince' => $updatedSince, 'folderId' => $folderId, 'userId' => $userId])
             ->addOrderBy('items.id', 'DESC');
 
         if ($hideRead === true) {
@@ -387,13 +383,13 @@ class ItemMapperV2 extends NewsMapperV2
 
     /**
      * @param string $userId
-     * @param float  $updatedSince
+     * @param int    $updatedSince
      * @param int    $feedType
      *
      * @return Item[]|Entity[]
      * @throws ServiceValidationException
      */
-    public function findAllAfter(string $userId, int $feedType, float $updatedSince): array
+    public function findAllAfter(string $userId, int $feedType, int $updatedSince): array
     {
         $builder = $this->db->getQueryBuilder();
 
@@ -403,10 +399,7 @@ class ItemMapperV2 extends NewsMapperV2
             ->andWhere('items.last_modified >= :updatedSince')
             ->andWhere('feeds.deleted_at = 0')
             ->andWhere('feeds.user_id = :userId')
-            ->setParameters([
-                'updatedSince' => number_format($updatedSince, 0, '.', ''),
-                'userId' => $userId,
-            ])
+            ->setParameters(['updatedSince' => $updatedSince, 'userId' => $userId])
             ->addOrderBy('items.id', 'DESC');
 
         switch ($feedType) {
